###################################################
### chunk number 1: 
###################################################
options("prompt" = "R> ", "continue" = "+ ", "useFancyQuotes" = FALSE)


###################################################
### chunk number 2: 
###################################################
library(mefa)
data(dol.count)
dol.count[1:16, ]


###################################################
### chunk number 3: 
###################################################
x1 <- stcs(dol.count)
str(x1)
unique(x1$count)


###################################################
### chunk number 4: 
###################################################
x2 <- stcs(dol.count, expand = TRUE)
str(x2)
sum(x2$count)
unique(x2$count)


###################################################
### chunk number 5: 
###################################################
x3 <- stcs(dol.count, drop.zero = TRUE)
str(x3)
unique(x3$count)


###################################################
### chunk number 6: 
###################################################
m1 <- mefa(x1)
m1
m1$xtab["LT1", ]


###################################################
### chunk number 7: 
###################################################
str(m1$xtab)
str(m1$segm)


###################################################
### chunk number 8: 
###################################################
mefa(x1, nested = TRUE)


###################################################
### chunk number 9: 
###################################################
mefa(x1, segment = FALSE)


###################################################
### chunk number 10: 
###################################################
data(dol.samp)
str(dol.samp)


###################################################
### chunk number 11: 
###################################################
data(dol.taxa)
str(dol.taxa)


###################################################
### chunk number 12: 
###################################################
mefa(x1, samp = dol.samp)
mefa(x1, taxa = dol.taxa)
m2 <- mefa(x1, samp = dol.samp, taxa = dol.taxa)
m2
str(m2$xtab)
str(m2$samp)
str(m2$taxa)


###################################################
### chunk number 13: 
###################################################
m2.sub <- mefa(x1, dol.samp[-c(1:5), ], dol.taxa[-c(1:80), ], xtab.fixed = FALSE)
m2.sub
str(m2.sub$xtab)
str(m2.sub$samp)
str(m2.sub$taxa)


###################################################
### chunk number 14: mefastr
###################################################
mefalogo()


###################################################
### chunk number 15: 
###################################################
dim(m2)
dimnames(m2)


###################################################
### chunk number 16: 
###################################################
summary(m2)


###################################################
### chunk number 17: 
###################################################
names(summary(m2))


###################################################
### chunk number 18: 
###################################################
summary(m2)$s.rich
summary(m2)$mfill


###################################################
### chunk number 19: plot
###################################################
opar <- par(mfrow = c(1, 2))
plot(m2, 1, main = "A")
plot(m2, 4, type = "rank", trafo = "log", main = "B")
par(opar)


###################################################
### chunk number 20: boxplot
###################################################
opar <- par(mfrow = c(1, 2))
boxplot(m2, 2, main = "A")
boxplot(m2, 3, main = "B")
par(opar)


###################################################
### chunk number 21: 
###################################################
molten <- melt(m2, "method")
str(molten)


###################################################
### chunk number 22: 
###################################################
m3 <- mefa(molten, dol.samp, dol.taxa)
m3


###################################################
### chunk number 23: image
###################################################
opar <- par(mfrow = c(1, 3))
image(m3, trafo = "log", sub = "all segments", main="A")
for (i in 1:2)
    image(m3, segm = i, trafo = "log",
    sub = dimnames(m3)$segm[i], main = LETTERS[i + 1])
par(opar)


###################################################
### chunk number 24: 
###################################################
ex1 <- m2[1:20, 11:15, "fresh"]
dim(ex1)
dim(ex1$samp)
dim(ex1$taxa)


###################################################
### chunk number 25: 
###################################################
ex2 <- m2[m2$samp$method == "time"]
levels(ex2$samp$method)
ex3 <- m2[m2$samp$method == "time", drop = TRUE]
levels(ex3$samp$method)


###################################################
### chunk number 26: 
###################################################
size.5 <- as.factor(is.na(m3$taxa$size) | m3$taxa$size < 5)
levels(size.5) <- c("large", "small")
m4 <- aggregate(m3, "microhab", size.5)
t(m4$xtab)
lapply(m4$segm, t)


###################################################
### chunk number 27: 
###################################################
set.seed(1234)
m5 <- m2[ , sample(1:dim(m2)[2], 10)]
report(m5, "report.tex", tex = TRUE, 
    segment = TRUE, taxa.name = 1, author.name = 2,
    drop.redundant = 1)


###################################################
### chunk number 28: 
###################################################
mod.amin <- glm(m2$xtab[, "amin"] ~ ., data = m2$samp, family = poisson)
summary(mod.amin)


###################################################
### chunk number 29: 
###################################################
library(MASS)
mod.abu <- glm.nb(summary(m2)$s.abu ~ .^2, data = m2$samp)
summary(mod.abu)


###################################################
### chunk number 30: 
###################################################
prop.fr <- cbind(summary(m2[ , , "fresh"])$s.abu, summary(m2)$s.abu)
mod.fr <- glm(prop.fr ~ .^2,
    data = m2$samp, family = binomial)
summary(mod.fr)


###################################################
### chunk number 31: 
###################################################
m.list <- list()
n1 <- rep(c("time", "quadrat"), each = 2)
n2 <- rep(c("fresh", "broken"), 2)
n3 <- paste(n1, n2, sep=".")
for (i in 1:4) {
    m.list[[n3[i]]] <-
    aggregate(m2[m2$samp$method == n1[i], , n2[i]], "microhab")
}


###################################################
### chunk number 32: clust
###################################################
opar <- par(mfrow=c(2, 2))
for (i in 1:4) {
    tmp <- hclust(dist(m.list[[i]]$xtab), "ward")
    plot(tmp, main = LETTERS[i], sub = names(m.list)[i], xlab = "")
}
par(opar)


